@@ -7,12 +7,14 @@ use PDF::COS::Tie::Hash;
 role PDF::Appearance
     does PDF::COS::Tie::Hash {
 
-# See [PDF 1.7 TABLE 8.19 Entries in an appearance dictionary]
-
     use PDF::COS;
     use PDF::COS::Tie;
     use PDF::COS::Stream;
 
+    # See [PDF 32000 Table 168 - Entries in an appearance dictionary]
+    ## use ISO_32000::Appearance;
+    ## also does ISO_32000::Appearance;
+
     my subset FormLike of PDF::COS::Stream where .<Subtype> ~~ 'Form'; # autoloaded PDF::XObject::Form
     my role AppearanceStatus
 	does PDF::COS::Tie::Hash {
@@ -29,8 +31,8 @@ role PDF::Appearance
 	PDF::COS.coerce($dict,  AppearanceStatus)
     }
 
-    has AppearanceEntry $.N is entry(:&coerce, :alias<normal>, :required); #| (Required) The annotation’s normal appearance.
-    has AppearanceEntry $.R is entry(:&coerce, :alias<rollover>);          #| (Optional) The annotation’s rollover appearance. Default value: the value of the N entry.
-    has AppearanceEntry $.D is entry(:&coerce, :alias<down>);              #| (Optional) The annotation’s down appearance. Default value: the value of the N entry.
+    has AppearanceEntry $.N is entry(:&coerce, :alias<normal>, :required); # (Required) The annotation’s normal appearance.
+    has AppearanceEntry $.R is entry(:&coerce, :alias<rollover>);          # (Optional) The annotation’s rollover appearance. Default value: the value of the N entry.
+    has AppearanceEntry $.D is entry(:&coerce, :alias<down>);              # (Optional) The annotation’s down appearance. Default value: the value of the N entry.
 
 }
