@@ -1,9 +1,11 @@
 use v6;
 
 use PDF::COS::Tie::Hash;
+use PDF::Class::Type;
 
 role PDF::Pattern
-    does PDF::COS::Tie::Hash {
+    does PDF::COS::Tie::Hash
+    does PDF::Class::Type::Subtyped {
 
     use PDF::COS::Tie;
     use PDF::COS::Name;
